@@ -17,7 +17,7 @@ enum AdvSettingsRows {DISK_CACHE,
                     #if LIBTORRENT_VERSION_NUM >= 1610
                       DISK_CACHE_TTL,
                     #endif
-                      OUTGOING_PORT_MIN, OUTGOING_PORT_MAX, IGNORE_LIMIT_LAN, RECHECK_COMPLETED, LIST_REFRESH, RESOLVE_COUNTRIES, RESOLVE_HOSTS, MAX_HALF_OPEN, SUPER_SEEDING, NETWORK_IFACE, NETWORK_ADDRESS, PROGRAM_NOTIFICATIONS, TRACKER_STATUS, TRACKER_PORT,
+                      OS_CACHE, OUTGOING_PORT_MIN, OUTGOING_PORT_MAX, IGNORE_LIMIT_LAN, RECHECK_COMPLETED, LIST_REFRESH, RESOLVE_COUNTRIES, RESOLVE_HOSTS, MAX_HALF_OPEN, SUPER_SEEDING, NETWORK_IFACE, NETWORK_LISTEN_IPV6, NETWORK_ADDRESS, PROGRAM_NOTIFICATIONS, TRACKER_STATUS, TRACKER_PORT,
                     #if defined(Q_WS_WIN) || defined(Q_WS_MAC)
                       UPDATE_CHECK,
                     #endif
@@ -33,9 +33,9 @@ class AdvancedSettings: public QTableWidget {
 
 private:
   QSpinBox spin_cache, outgoing_ports_min, outgoing_ports_max, spin_list_refresh, spin_maxhalfopen, spin_tracker_port;
-  QCheckBox cb_ignore_limits_lan, cb_recheck_completed, cb_resolve_countries, cb_resolve_hosts,
+  QCheckBox cb_os_cache, cb_ignore_limits_lan, cb_recheck_completed, cb_resolve_countries, cb_resolve_hosts,
   cb_super_seeding, cb_program_notifications, cb_tracker_status, cb_confirm_torrent_deletion,
-  cb_enable_tracker_ext;
+  cb_enable_tracker_ext, cb_listen_ipv6;
   QComboBox combo_iface;
 #if LIBTORRENT_VERSION_NUM >= 1610
   QSpinBox spin_cache_ttl;
@@ -79,6 +79,8 @@ public slots:
 #if LIBTORRENT_VERSION_NUM >= 1610
     pref.setDiskCacheTTL(spin_cache_ttl.value());
 #endif
+    // Enable OS cache
+    pref.setOsCache(cb_os_cache.isChecked());
     // Outgoing ports
     pref.setOutgoingPortsMin(outgoing_ports_min.value());
     pref.setOutgoingPortsMax(outgoing_ports_max.value());
@@ -104,6 +106,8 @@ public slots:
       pref.setNetworkInterface(combo_iface.itemData(combo_iface.currentIndex()).toString());
       pref.setNetworkInterfaceName(combo_iface.currentText());
     }
+    // Listen on IPv6 address
+    pref.setListenIPv6(cb_listen_ipv6.isChecked());
     // Network address
     QHostAddress addr(txt_network_address.text().trimmed());
     if (addr.isNull())
@@ -178,7 +182,15 @@ private slots:
     const Preferences pref;
     // Disk write cache
     spin_cache.setMinimum(0);
-    spin_cache.setMaximum(2048);
+    // When build as 32bit binary, set the maximum at less than 2GB to prevent crashes.
+    // These macros may not be available on compilers other than MSVC and GCC
+#if !defined(_M_X64) && !defined(__amd64__)
+    //1800MiB to leave 248MiB room to the rest of program data in RAM
+    spin_cache.setMaximum(1800);
+#else
+    // 4GiB
+    spin_cache.setMaximum(4*1024);
+#endif
     spin_cache.setValue(pref.diskCacheSize());
     updateCacheSpinSuffix(spin_cache.value());
     setRow(DISK_CACHE, tr("Disk write cache size"), &spin_cache);
@@ -190,6 +202,9 @@ private slots:
     spin_cache_ttl.setSuffix(tr(" s", " seconds"));
     setRow(DISK_CACHE_TTL, tr("Disk cache expiry interval"), &spin_cache_ttl);
 #endif
+    // Enable OS cache
+    cb_os_cache.setChecked(pref.osCache());
+    setRow(OS_CACHE, tr("Enable OS cache"), &cb_os_cache);
     // Outgoing port Min
     outgoing_ports_min.setMinimum(0);
     outgoing_ports_min.setMaximum(65535);
@@ -246,6 +261,9 @@ private slots:
       combo_iface.setCurrentIndex(i);
     }
     setRow(NETWORK_IFACE, tr("Network Interface (requires restart)"), &combo_iface);
+    // Listen on IPv6 address
+    cb_listen_ipv6.setChecked(pref.getListenIPv6());
+    setRow(NETWORK_LISTEN_IPV6, tr("Listen on IPv6 address (requires restart)"), &cb_listen_ipv6);
     // Network address
     txt_network_address.setText(pref.getNetworkAddress());
     setRow(NETWORK_ADDRESS, tr("IP Address to report to trackers (requires restart)"), &txt_network_address);
