@@ -106,7 +106,7 @@ QVariantHash RssDownloadRule::toVariantHash() const
   return hash;
 }
 
-bool RssDownloadRule::operator==(const RssDownloadRule &other) {
+bool RssDownloadRule::operator==(const RssDownloadRule &other) const {
   return m_name == other.name();
 }
 
