@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 
-#VERSION: 1.22
+#VERSION: 1.23
 #AUTHORS: BTDigg team (research@btdigg.org)
 #
 #                    GNU GENERAL PUBLIC LICENSE
@@ -66,7 +66,7 @@ class btdigg(object):
         pass
         
     def search(self, what, cat='all'):
-        req = what.replace('+', ' ')
+        req = urllib.unquote(what)
         u = urllib2.urlopen('https://api.btdigg.org/api/public-8e9a50f8335b964f/s01?%s' % (urllib.urlencode(dict(q = req)),))
 
         try:
