@@ -41,7 +41,6 @@
 #include "searchtab.h"
 #include "supportedengines.h"
 
-class DownloadThread;
 class SearchEngine;
 class MainWindow;
 class LineEdit;
@@ -105,12 +104,6 @@ protected slots:
   void downloadFinished(int exitcode, QProcess::ExitStatus);
   void fillCatCombobox();
   void searchTextEdited(QString);
-#ifdef Q_WS_WIN
-  bool addPythonPathToEnv();
-  void installPython();
-  void pythonDownloadSuccess(QString url, QString file_path);
-  void pythonDownloadFailure(QString url, QString error);
-#endif
 
 private slots:
   void on_goToDescBtn_clicked();
@@ -130,9 +123,6 @@ private:
   QList<QPointer<SearchTab> > all_tab; // To store all tabs
   const SearchCategories full_cat_names;
   MainWindow *mp_mainWindow;
-#ifdef Q_WS_WIN
-  bool has_python;
-#endif
 };
 
 #endif
