@@ -31,24 +31,23 @@
 #ifndef TRANSFERLISTWIDGET_H
 #define TRANSFERLISTWIDGET_H
 
-#include <QShortcut>
 #include <QTreeView>
 #include <libtorrent/version.hpp>
-#include "qtorrenthandle.h"
-#include "transferlistsortmodel.h"
 
 class QBtSession;
-class TransferListDelegate;
+class QTorrentHandle;
 class MainWindow;
+class TransferListDelegate;
+class TransferListSortModel;
 class TorrentModel;
+class StatusSortFilterProxyModel;
 
 QT_BEGIN_NAMESPACE
+class QShortcut;
 class QSortFilterProxyModel;
 class QStandardItemModel;
 QT_END_NAMESPACE
 
-enum TorrentFilter {FILTER_ALL, FILTER_DOWNLOADING, FILTER_COMPLETED, FILTER_PAUSED, FILTER_ACTIVE, FILTER_INACTIVE};
-
 class TransferListWidget: public QTreeView {
   Q_OBJECT
 
@@ -113,7 +112,7 @@ private:
   TransferListDelegate *listDelegate;
   TorrentModel *listModel;
   TransferListSortModel *nameFilterModel;
-  QSortFilterProxyModel *statusFilterModel;
+  StatusSortFilterProxyModel *statusFilterModel;
   QSortFilterProxyModel *labelFilterModel;
   QBtSession* BTSession;
   MainWindow *main_window;
