@@ -79,9 +79,8 @@ var dynamicTable = new Class	({
 			case 8: // Down Speed
 				var sizeStrToFloat = function(mystr) {
 					var val1 = mystr.split(' ');
-					val1[0] = val1[0].replace(",", "."); // toFloat() cannot parse comma as decimal point
-					var val1num = val1[0].toFloat();
-					var unit = val1[1].split('/')[0]; // get an unit numerator only (to support speed values)
+					var val1num = val1[0].toFloat()
+					var unit = val1[1];
 					switch(unit) {
 						case '_(TiB)':
 							return val1num*1099511627776;
@@ -112,11 +111,9 @@ var dynamicTable = new Class	({
 					return (tr2.getElements('td')[i].get('html').split(' ')[0].toInt() - tr1.getElements('td')[i].get('html').split(' ')[0].toInt());
 			default: // Ratio
 				var ratio1 = tr1.getElements('td')[i].get('html');
-				ratio1 = ratio1.replace(",", "."); // toFloat() cannot parse comma as decimal point
 				if(ratio1 == '∞')
 					ratio1 = '101.0';
 				var ratio2 = tr2.getElements('td')[i].get('html');
-				ratio2 = ratio2.replace(",", "."); // toFloat() cannot parse comma as decimal point
 				if(ratio2 == '∞')
 					ratio2 = '101.0';
 				if(!reverseSort)
